/*-----------------------------------------------------------------
  All code is provided for EDUCATIONAL purposes ONLY. There is no
  warranty and no support.

  Released under the MIT License  - see
  http://www.opensource.org/licenses/mit-license.php

  thermostat2 by Jack Botner

  main.h
-----------------------------------------------------------------*/
#ifndef _MAIN_H_
#define _MAIN_H_

#include "common.h"

#define INIT_TIMER0			( 256 - 196 )
#define INIT_TIMER2			( 256 - 250 )

#define SET_TEMP_DELTA   	5		// effect of up and down buttons on temperature
#define SYSTEM_DELAY_SEC 	5		// delay system response to user input

#define MAX_CHECKS       	6		// number of tests before a switch is debounced

// The TC1047A is specified to plus/minus 2 degrees C, so some
// correction may be required.
#define TEMP_CORRECTION		10		// tenths of degrees C

// Adjusting OSCCAL can get Timer0 to generate 25ms interrupts
#define OSCCAL_DEFAULT      100

// Hysteresis constants (tenths degrees C) are the amount above and below the
// set temperature that the furnace or A/C will run. The wider the range, the
// longer the unit runs and the greater the temperature variation. There is a
// balance between comfort and efficient operation of the unit. There is also
// some dependency on the thermal mass of the temperature sensor; less mass
// requires greater hysteresis and vice-versa. There is also some dependency on
// the ability of the unit to change the temperature over time. These are
// initial values, which can be changed via customization.
#define HYSTERESIS_HEAT     5       // 10ths degrees C of hysteresis
#define HYSTERESIS_COOL     2

// System modes bits
#define MODE_FAN_ON			0
#define MODE_HEAT_ON		1
#define MODE_COOL_ON		2

// Events bits
#define EVENT_UPDATE_LCD		0
#define EVENT_ANALYZE_STATE		1
#define EVENT_CONVERT_TEMP		2
#define EVENT_UPDATE_EEPROM		3
#define EVENT_BUTTON_PRESSED	4
#define EVENT_ENCODER_UP		5
#define EVENT_ENCODER_DOWN		6

#define EVENT2_ONE_SECOND       0
#define EVENT2_5_SECONDS        1

// De-bounced switches bits
#define ENC_SWITCH_A			0
#define ENC_SWITCH_B			1
#define ENC_SWITCH_PB			2

// Rotary encoder port defines
#define ENCODER_PORT			PINB
#define ENCODER_A				PB1
#define ENCODER_B				PB0
#define ENCODER_PB				PB2

// Relay port defines
#define RELAY_PORT				PORTC
#define RELAY_HEAT				PC1
#define RELAY_COOL				PC2
#define RELAY_FAN				PC3

// To output Timer0 25.088 ms signal
#define DIAG_PORT_OUT           PORTC
#define DIAG_PORT_IN            PINC
#define DIAG_PIN                PC5
 
// EEPROM stuff
typedef struct _MY_EEPROM_DATA
{
  uint16_t	uiSetTemp10C_Heat;			// last set temperature (heat)
  uint16_t	uiSetTemp10C_Cool;			// last set temperature (cool)
  uint8_t	ucSystemMode;				// system mode flags
  uint8_t	ucHysteresis_Heat;			// heat hysteresis, 10ths degrees C
  uint8_t	ucHysteresis_Cool;			// cool hysteresis, 10ths degrees C
  uint8_t   ucOsccal;                   // osccal adjustment
}
MY_EEPROM_DATA;

// Functions

void    calculate_humidity(void);
void    display_humidity(void);
void	program_hysteresis(void);
void	program_mode(void);
void	program_fan(void);
void    program_osccal(void);

#endif  //_MAIN_H_
